@@ -17,9 +17,10 @@ class ConfigurableDGP(BaseDataGenusProcessor):
     @property
     def module(self):
         if self._per_taxonomy:
-            return getattr(self.context.taxonomy, self._kind)
-        else:
-            return getattr(self.context.taxonomies.get('_common_'), self._kind)
+            ret = getattr(self.context.taxonomy, self._kind)
+            if ret and ret.module:
+                return ret
+        return getattr(self.context.taxonomies.get('_common_'), self._kind)
 
     @property
     def flows(self):
